using BinaryProvider
using CxxWrap # this is needed for opening the dependency lib. Otherwise Libdl.dlopen fails

##################### Fastjet ###########################s
const fjversion = "v3.3.2"
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    LibraryProduct(prefix, ["libfastjetwrap"], :libfastjetwrap),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/jstrube/FastJetWrapBuilder/releases/download/v0.3"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/FastJetWrapBuilder.v0.3.0.x86_64-apple-darwin14-gcc7.tar.gz", "d28f8e6c1f676231e6ed28a68376c923d26ee09302e724928db06e3a0e2d089f"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/FastJetWrapBuilder.v0.3.0.x86_64-apple-darwin14-gcc8.tar.gz", "ecd8fd73c0335fefa791f9995f574f82150e396d30e434a0c0a170f156acc569"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc7, :cxx11)) => ("$bin_prefix/FastJetWrapBuilder.v0.3.0.x86_64-linux-gnu-gcc7-cxx11.tar.gz", "1c917c403fc1d6a2e2531c7f3176686b4de0cc146f270f54737e6137def6c614"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc8, :cxx11)) => ("$bin_prefix/FastJetWrapBuilder.v0.3.0.x86_64-linux-gnu-gcc8-cxx11.tar.gz", "cadd0dda6125f5ee10389a66cf54af7d5b5bf866fdc02c90f680df23e0f5ecb7"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps.jl"), products, verbose=verbose)
